#
# spec file for package python-djangorestframework
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-djangorestframework
Version:        2.4.4
Release:        2.1
Summary:        A Lightweight REST Framework for Django
License:        BSD-2-Clause
Group:          Development/Languages/Python
Url:            http://django-rest-framework.org
Source:         http://pypi.python.org/packages/source/d/djangorestframework/djangorestframework-%{version}.tar.gz
BuildRequires:  python-devel
BuildRequires:  python-django
BuildRequires:  python-setuptools
Requires:       python-django
Provides:       python-django-rest-framework = %{version}
Obsoletes:      python-django-rest-framework < %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} && 0%{?suse_version} > 1110
BuildArch:      noarch
%endif

%description
Django REST framework is a lightweight library that makes it easy to build Web
APIs. It is designed as a modular and easy to customize architecture, based on
Django's class based views.

Web APIs built using REST framework are fully self-describing and web
browseable - a huge useability win for your developers. It also supports a wide
range of media types, authentication and permission policies out of the box.

%prep
%setup -q -n djangorestframework-%{version}

%build
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

%files
%defattr(-,root,root,-)
%{python_sitelib}/*

%changelog
* Thu Mar 24 2016 ejackson@suse.com
- fix obsolete tag
* Thu Oct 22 2015 lenz@openattic.org
- Downgrade to version 2.4.4 to match openATTIC's requirement
* Fri Jul 24 2015 matwey.kornilov@gmail.com
- Update to version 3.1.3:
  * A super-smart cursor pagination scheme.
  * An improved pagination API, supporting header or in-body pagination styles.
  * Pagination controls rendering in the browsable API.
  * Better support for API versioning.
  * Built-in internationalization support.
  * Support for Django 1.8's HStoreField and ArrayField.
* Mon Jul 13 2015 toddrme2178@gmail.com
- Fix building on SLES 11
* Sun Jan 11 2015 p.drouand@gmail.com
- Update to version 3.0.3
  * Fix MinValueValidator on models.DateField. (#2369)
  * Fix serializer missing context when pagination is used. (#2355)
  * Namespaced router URLs are now supported by the DefaultRouter. (#2351)
  * required=False allows omission of value for output. (#2342)
  * Use textarea input for models.TextField. (#2340)
  * Use custom ListSerializer for pagination if required. (#2331, #2327)
  * Better behavior with null and '' for blank HTML fields. (#2330)
  * Ensure fields in exclude are model fields. (#2319)
  * Fix IntegerField and max_length argument incompatibility. (#2317)
  * Fix the YAML encoder for 3.0 serializers. (#2315, #2283)
  * Fix the behavior of empty HTML fields. (#2311, #1101)
  * Fix Metaclass attribute depth ignoring fields attribute. (#2287)
  * Fix format_suffix_patterns to work with Django's i18n_patterns. (#2278)
  * Ability to customize router URLs for custom actions, using url_path. (#2010)
  * Don't install Django REST Framework as egg. (#2386)
- Provide and obsolete redundant python-django-rest-framework
* Fri Nov 29 2013 david.bahid@emc.com
- update to 2.3.12
  * removed patch to removed unicode support to enable SLES11
    not needed for SLES11 SP3 with python 2.6.8 and SP2 fails
    even if updated patch is applied (and SP3 fails with patch).
  * Move to 2.3 base release for the restframework
    introduces the ViewSet and Router classes
    simplified generic view classes
    easier serializers
    more flexible filtering
    simpler URL lookups
    file upload parser
    decimal field
    add reverse relationships to the fields option on a ModelSerializer class
    get_related_field and get_nested_field method signatures have now changed
    mechanics of names and descriptions used in the browseable API are
    generated has been modified and cleaned up
  * see http://django-rest-framework.org/topics/2.3-announcement for more details
- Remove django-rest-framework-no-unicode-literals.diff; older python
  versions are unsupported anyway
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Sat Feb 16 2013 jfunk@funktronics.ca
- Update to 2.2.0
  * Python 3 support.
  * Added a post_save() hook to the generic views.
  * Allow serializers to handle dicts as well as objects.
  * Deprecate ManyRelatedField() syntax in favor of RelatedField(many=True)
  * Deprecate null=True on relations in favor of required=False.
  * Deprecate blank=True on CharFields, just use required=False.
  * Deprecate optional obj argument in permissions checks in favor of
    has_object_permission.
  * Deprecate implicit hyperlinked relations behavior.
  * Bugfix: Fix broken DjangoModelPermissions.
  * Bugfix: Allow serializer output to be cached.
  * Bugfix: Fix styling on browsable API login.
  * Bugfix: Fix issue with deserializing empty to-many relations.
  * Bugfix: Ensure model field validation is still applied for ModelSerializer
    subclasses with an custom .restore_object() method.
- Disable unicode_literals feature on older Python
* Mon Jan 21 2013 jfunk@funktronics.ca
- Update to 2.1.16:
  * Deprecate django.utils.simplejson in favor of Python 2.6's built-in json
    module.
  * Bugfix: auto_now, auto_now_add and other editable=False fields now default
    to read-only.
  * Bugfix: PK fields now only default to read-only if they are an AutoField
    or if editable=False.
  * Bugfix: Validation errors instead of exceptions when serializers receive
    incorrect types.
  * Bugfix: Validation errors instead of exceptions when related fields
    receive incorrect types.
  * Bugfix: Handle ObjectDoesNotExist exception when serializing null reverse
    one-to-one
  * Note: Prior to 2.1.16, The Decimals would render in JSON using floating
    point if simplejson was installed, but otherwise render using string
    notation. Now that use of simplejson has been deprecated, Decimals will
    consistently render using string notation. See #582 for more details.
- 2.1.15
  * Added PATCH support.
  * Added RetrieveUpdateAPIView.
  * Remove unused internal save_m2m flag on ModelSerializer.save().
  * Tweak behavior of hyperlinked fields with an explicit format suffix.
  * Relation changes are now persisted in .save() instead of in
    .restore_object().
  * Bugfix: Fix issue with FileField raising exception instead of validation
    error when files=None.
  * Bugfix: Partial updates should not set default values if field is not
    included.
* Tue Jan  1 2013 jfunk@funktronics.ca
- Update to 2.1.14:
  * Bugfix: ModelSerializers now include reverse FK fields on creation.
  * Bugfix: Model fields with blank=True are now required=False by default.
  * Bugfix: Nested serializers now support nullable relationships.
  * Note: From 2.1.14 onwards, relational fields move out of the fields.py
    module and into the new relations.py module, in order to seperate them
    from regular data type fields, such as CharField and IntegerField. This
    change will not affect user code, so long as it's following the
    recommended import style of from rest_framework import serializers and
    refering to fields using the style serializers.PrimaryKeyRelatedField.
- 2.1.13
  * Support configurable STATICFILES_STORAGE storage.
  * Bugfix: Related fields now respect the required flag, and may be
    required=False.
- 2.1.12
  * Bugfix: Fix bug that could occur using ChoiceField.
  * Bugfix: Fix exception in browseable API on DELETE.
  * Bugfix: Fix issue where pk was was being set to a string if set by URL
    kwarg.
- 2.1.11
  * Bugfix: Fix issue with M2M fields in browseable API.
- 2.1.10
  * Bugfix: Ensure read-only fields don't have model validation applied.
  * Bugfix: Fix hyperlinked fields in paginated results.
- 2.1.9
  * Bugfix: Fix broken nested serialization.
  * Bugfix: Fix Meta.fields only working as tuple not as list.
  * Bugfix: Edge case if unnecessarily specifying required=False on read only
    field.
- 2.1.8
  * Fix for creating nullable Foreign Keys with '' as well as None.
  * Added null=<bool> related field option.
- 2.1.7
  * Serializers now properly support nullable Foreign Keys.
  * Serializer validation now includes model field validation, such as
    uniqueness constraints.
  * Support 'true' and 'false' string values for BooleanField.
  * Added pickle support for serialized data.
  * Support source='dotted.notation' style for nested serializers.
  * Make Request.user settable.
  * Bugfix: Fix RegexField to work with BrowsableAPIRenderer
- 2.1.6
  * Bugfix: Unfix DjangoModelPermissions. (I am a doofus.)
- 2.1.5
  * Bugfix: Fix DjangoModelPermissions.
- 2.1.4
  * Support for partial updates with serializers.
  * Added RegexField.
  * Added SerializerMethodField.
  * Serializer performance improvements.
  * Added obtain_token_view to get tokens when using TokenAuthentication.
  * Bugfix: Django 1.5 configurable user support for TokenAuthentication.
* Wed Nov 21 2012 jfunk@funktronics.ca
- Update to 2.1.3:
  * Added FileField and ImageField. For use with MultiPartParser.
  * Added URLField and SlugField.
  * Support for read_only_fields on ModelSerializer classes.
  * Support for clients overriding the pagination page sizes. Use the
    PAGINATE_BY_PARAM setting or set the paginate_by_param attribute on a
    generic view.
  * 201 Responses now return a 'Location' header.
  * Bugfix: Serializer fields now respect max_length.
* Tue Nov 13 2012 jfunk@funktronics.ca
- Update to 2.1.2:
  * Filtering support.
  * Bugfix: Support creation of objects with reverse M2M relations.
- 2.1.1
  * Support use of HTML exception templates. Eg. 403.html
  * Hyperlinked fields take optional slug_field, slug_url_kwarg and
    pk_url_kwarg arguments.
  * Bugfix: Deal with optional trailing slashs properly when generating
    breadcrumbs.
  * Bugfix: Make textareas same width as other fields in browsable API.
  * Private API change: .get_serializer now uses same instance and data
    ordering as serializer initialization.
- 2.1.0
  * Serializer instance and data keyword args have their position swapped.
  * queryset argument is now optional on writable model fields.
  * Hyperlinked related fields optionally take slug_field and slug_url_kwarg
    arguments.
  * Support Django's cache framework.
  * Minor field improvements. (Don't stringify dicts, more robust many-pk
    fields.)
  * Bugfix: Support choice field in Browseable API.
  * Bugfix: Related fields with read_only=True do not require a queryset
    argument.
- 2.0.2
  * Fix issues with pk related fields in the browsable API.
- 2.0.1
  * Add support for relational fields in the browsable API.
  * Added SlugRelatedField and ManySlugRelatedField.
  * If PUT creates an instance return '201 Created', instead of '200 OK'.
- 2.0.0
  * Fix all of the things. (Well, almost.)
  * For more information please see the 2.0 announcement.
- 0.4.0
  * Supports Django 1.5.
  * Fixes issues with 'HEAD' method.
  * Allow views to specify template used by TemplateRenderer
  * More consistent error responses
  * Some serializer fixes
  * Fix internet explorer ajax behaviour
  * Minor xml and yaml fixes
  * Improve setup (eg use staticfiles, not the defunct ADMIN_MEDIA_PREFIX)
  * Sensible absolute URL generation, not using hacky set_script_prefix
- 0.3.3
  * Added DjangoModelPermissions class to support django.contrib.auth style
    permissions.
  * Use staticfiles for css files.
  * Easier to override. Won't conflict with customised admin styles (eg
    grappelli)
  * Templates are now nicely namespaced.
  * Allows easier overriding.
  * Drop implied 'pk' filter if last arg in urlconf is unnamed.
  * Too magical. Explict is better than implicit.
  * Saner template variable autoescaping.
  * Tider setup.py
  * Updated for URLObject 2.0
  * Bug with PerUserThrottling when user contains unicode chars.
- 0.3.2
  * Fix 403 for POST and PUT from the UI with UserLoggedInAuthentication
    (#115)
  * serialize_model method in serializer.py may cause wrong value (#73)
  * Fix Error when clicking OPTIONS button (#146)
  * And many other fixes
  * Remove short status codes
  * Zen of Python: "There should be one-- and preferably only one --obvious
    way to do it."
  * get_name, get_description become methods on the view - makes them
    overridable.
  * Improved model mixin API - Hooks for build_query, get_instance_data,
    get_model, get_queryset, get_ordering
- Run tests
- Ran spec-cleaner on spec
* Thu Jan 12 2012 jfunk@funktronics.ca
- Initial release
